==> 0.0.1.tar.gz: android/src/main/java/com/example/calculator_plugin/CalculatorPlugin.java <==
package com.example.calculator_plugin;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** CalculatorPlugin */
public class CalculatorPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "calculator_plugin");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if (call.method.equals("calculatorAdd"))
    {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      System.out.println(num1+num2);
    }

    else if (call.method.equals("calculatorSub"))
    {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      System.out.println(num1-num2);
    }

    else if (call.method.equals("calculatorMul"))
    {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      System.out.println(num1*num2);
    }

    else if (call.method.equals("calculatorDiv"))
    {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      System.out.println(num1/num2);
    }


    else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}

==> 0.0.2.tar.gz: android/src/main/java/com/example/calculator_plugin/CalculatorPlugin.java <==
package com.example.calculator_plugin;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

public class CalculatorPlugin implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "plugin_flutter_testing");
    channel.setMethodCallHandler(this);.
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    }
    else if (call.method.equals("calculatorAdd")) {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      result.success(num1+num2);
    }

    else if (call.method.equals("calculatorSub")) {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      result.success(num1-num2);
    }
    else if (call.method.equals("calculatorMul")) {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      result.success(num1*num2);
    }
    else if (call.method.equals("calculatorDiv")) {
      int num1 = call.argument("num1");
      int num2 = call.argument("num2");
      if (num1 == 0 || num2 == 0) {
        result.success("You can not divide by or with a zero!");
      }
      else if (num2 == 0) {
        result.success("You cannot divide by zero!");
      }
      else {
        result.success(num1 / num2);
      }
    }



    else {
      result.notImplemented();
    }
  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
